import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Be-B6Vh7.js";import{B as y}from"./BaseLayout-BTvuKtpy.js";import{e as l,Z as _,a8 as b,aO as u,aK as v,aL as g,h as f,y as h,D as a,U as s,N as w,ai as S,f as k,w as n,an as B,m as i,j as I}from"./jwt-decode.esm-CO6urJAh.js";import{u as L}from"./editor-BVoKOFAX.js";import{A as $}from"./index-DCpkwTAP.js";import"./logo-BiWG9_W5.js";import"./Logo-h7ffuFgH.js";import"./ts.worker-DsjCRRg_.js";import"./workspaceStore-DFXmL_RZ.js";import"./userStore-CYK2BCng.js";import"./runnerData-afXvcWZM.js";import"./url-BPgbxcv5.js";import"./colorHelpers-gNFg7P74.js";import"./useCodebaseEvents-DVz4mBNr.js";import"./contracts.generated-C8DxD8-a.js";import"./router-CryK9Z4s.js";import"./constants-3jBOmiPn.js";import"./linters-BaO49k1c.js";import"./asyncComputed-4JIY0dta.js";import"./index-THfhzwp1.js";import"./index-CjZYxt4w.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="824ed998-2185-4fc0-b86b-aef88c1b4f45",e._sentryDebugIdIdentifier="sentry-dbid-824ed998-2185-4fc0-b86b-aef88c1b4f45")}catch{}})();const D=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),x={class:"v-spinner"};function K(e,r,o,c,d,p){return v((f(),h("div",x,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(D,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),c=L();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I($),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[a("div",R,[i(P)])]),_:1}))}}),re=u(j,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-qkI-xp6V.js.map
