import{N as l}from"./Navbar-B5txojzN.js";import{B as f}from"./BaseLayout-BTvuKtpy.js";import{C as b}from"./ContentLayout-BobnAQhp.js";import{e as g,an as _,b as r,ab as v,f as e,h as i,w as n,m as c,g as y}from"./jwt-decode.esm-CO6urJAh.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-vpbb1jUp.js";import{u as z}from"./projectsStore-BFXA42A4.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-EZfkV7iy.js";import"./constants-3jBOmiPn.js";import"./keyboard-BHSHbKug.js";import"./os-CyXon4ff.js";import"./router-BH9hE3RB.js";import"./ts.worker-DsjCRRg_.js";import"./organization-6lFJkxyL.js";import"./project-yy_XM24Y.js";import"./record-DUtA_nnv.js";import"./tables-CP3g5y6m.js";import"./string-DL9mKDWX.js";import"./organizationSwitcher-DwV4Q8sr.js";import"./folder-Bo_xgLGf.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CRUIX9OA.js";import"./member-Zjpdd31Z.js";import"./index-D6koXnfe.js";import"./index-CzHxe9W-.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-X5_Vw5t2.js";import"./PhNotePencil.vue-CiDX4Bu7.js";import"./PhSignOut.vue-DPcB7Vv7.js";import"./index-THfhzwp1.js";import"./index-CjZYxt4w.js";import"./PhPlus.vue-DQ_kjuHy.js";import"./omniChatStore-DdqtHKzE.js";import"./contracts.generated-C8DxD8-a.js";import"./runnerData-afXvcWZM.js";import"./url-BPgbxcv5.js";import"./colorHelpers-gNFg7P74.js";import"./uuid-D_qOmTQH.js";import"./PhCopySimple.vue-1OTWe2xU.js";import"./index-DCpkwTAP.js";import"./index-Bn9Ab_0k.js";import"./ant-design-B-3i7Axi.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="bbc85809-5490-4c2b-8f69-0ab06b10060f",t._sentryDebugIdIdentifier="sentry-dbid-bbc85809-5490-4c2b-8f69-0ab06b10060f")}catch{}})();const ct=g({__name:"Organization",setup(t){const o=_(),m=z(),p=r(()=>o.params.organizationId),a=r(()=>m.fetchedState?.organization),u=r(()=>a.value?{organizationId:a.value.id}:void 0),s=r(()=>a.value?.billingMetadata);return(I,C)=>{const d=v("RouterView");return i(),e(f,null,{navbar:n(()=>[c(l,{"use-cascader":!0,"cascader-props":u.value},null,8,["cascader-props"])]),content:n(()=>[c(b,null,{default:n(()=>[s.value?(i(),e(w,{key:0,"billing-metadata":s.value,"organization-id":p.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),e(d,{key:p.value}))]),_:1})]),_:1})}}});export{ct as default};
//# sourceMappingURL=Organization-8AihOAQG.js.map
