import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang-BQW7gZgz.js";import{e as n,an as s,f as m,h as a,j as c}from"./jwt-decode.esm-CO6urJAh.js";import"./router-BH9hE3RB.js";import"./ts.worker-DsjCRRg_.js";import"./fetch-BlCbZ9cl.js";import"./record-DUtA_nnv.js";import"./SaveButton-D4ArcxfR.js";import"./ExclamationCircleOutlined-CIJS10um.js";import"./CrudView-BvbhkDiO.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-Dj3bdkA_.js";import"./constants-3jBOmiPn.js";import"./url-BPgbxcv5.js";import"./PhDotsThreeVertical.vue-CRAZ7pf8.js";import"./index-THfhzwp1.js";import"./asyncComputed-4JIY0dta.js";import"./omniChatStore-DdqtHKzE.js";import"./contracts.generated-C8DxD8-a.js";import"./runnerData-afXvcWZM.js";import"./colorHelpers-gNFg7P74.js";import"./uuid-D_qOmTQH.js";import"./PhCopySimple.vue-1OTWe2xU.js";import"./PhPencil.vue-Csw3tfCw.js";import"./useCodebaseEvents-DVz4mBNr.js";import"./index-Bn9Ab_0k.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="6436b2cc-137d-4898-ba94-673e6300bb13",o._sentryDebugIdIdentifier="sentry-dbid-6436b2cc-137d-4898-ba94-673e6300bb13")}catch{}})();const G=n({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,f)=>(a(),m(i,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-DCq1g4w2.js.map
